@@ -17,9 +17,9 @@ def subgraph(name, period):
     )
     graph.add_precedence(time, printer)
 
-    timer = aiocells.source(functools.partial(
+    timer = functools.partial(
         aiocells.timer, period, time
-    ))
+    )
     graph.add_precedence(timer, time)
 
     return graph
@@ -32,17 +32,18 @@ async def async_main():
     subgraph_1 = subgraph("graph_1", 0.7)
     subgraph_2 = subgraph("graph_2", 1.5)
 
-    graph.add_node(aiocells.source(
-        functools.partial(aiocells.compute_flow, subgraph_1)))
-    graph.add_node(aiocells.source(
-        functools.partial(aiocells.compute_flow, subgraph_2)))
+    graph.add_node(functools.partial(aiocells.compute_flow, subgraph_1))
+    graph.add_node(functools.partial(aiocells.compute_flow, subgraph_2))
 
     print()
-    print("Ctrl-C to exit the demo")
+    print("Demo will complete in 10 iterations. Ctrl-C to cancel.")
     print()
 
+    iteration_count = 0
     while await aiocells.compute_flow(graph):
-        pass
+        iteration_count += 1
+        if iteration_count > 10:
+            await aiocells.cancel_flow(graph)
 
 
 def main():
